@@ -19,6 +19,5 @@ def subset(client):
     client.run()
 
 
-split_subset = launchable.CommonSplitSubsetImpls(
-    __name__, seperator=',').split_subset()
+split_subset = launchable.CommonSplitSubsetImpls(__name__, seperator=',').split_subset()
 record_tests = launchable.CommonRecordTestImpls(__name__).report_files()
