@@ -4,7 +4,8 @@ import shutil
 import tempfile
 from unittest import mock
 
-import responses
+import responses  # type: ignore
+
 from launchable.utils.session import SESSION_DIR_KEY, clean_session_files, read_build
 from tests.cli_test_case import CliTestCase
 
@@ -36,13 +37,11 @@ class BuildTest(CliTestCase):
 
         self.assertEqual(read_build(), None)
 
-        result = self.cli("record", "build",
-                          "--no-commit-collection", "--name", self.build_name)
+        result = self.cli("record", "build", "--no-commit-collection", "--name", self.build_name)
         self.assertEqual(result.exit_code, 0)
 
         # Name & Path should both reflect the submodule path
-        self.assertTrue(
-            "| ./bar-zot | ./bar-zot | 8bccab48338219e73c3118ad71c8c98fbd32a4be |" in result.stdout)
+        self.assertTrue("| ./bar-zot | ./bar-zot | 8bccab48338219e73c3118ad71c8c98fbd32a4be |" in result.stdout)
 
         payload = json.loads(responses.calls[0].request.body.decode())
         self.assert_json_orderless_equal(
@@ -77,8 +76,7 @@ class BuildTest(CliTestCase):
 
         self.assertEqual(read_build(), None)
 
-        result = self.cli("record", "build",
-                          "--no-commit-collection", "--no-submodules", "--name", self.build_name)
+        result = self.cli("record", "build", "--no-commit-collection", "--no-submodules", "--name", self.build_name)
         self.assertEqual(result.exit_code, 0)
 
         payload = json.loads(responses.calls[0].request.body.decode())
@@ -103,10 +101,8 @@ class BuildTest(CliTestCase):
             os.chdir(self.dir)
             self.assertEqual(read_build(), None)
 
-            result = self.cli("record", "build",
-                              "--no-commit-collection",
-                              "--commit", ".=c50f5de0f06fe16afa4fd1dd615e4903e40b42a2",
-                              "--name", self.build_name)
+            self.cli("record", "build", "--no-commit-collection", "--commit",
+                     ".=c50f5de0f06fe16afa4fd1dd615e4903e40b42a2", "--name", self.build_name)
 
             payload = json.loads(responses.calls[0].request.body.decode())
             self.assert_json_orderless_equal(
