@@ -6,6 +6,7 @@ from pathlib import Path
 from unittest import mock
 
 import responses  # type: ignore
+
 from launchable.utils.http_client import get_base_url
 from launchable.utils.session import write_build
 from tests.cli_test_case import CliTestCase
@@ -13,8 +14,7 @@ from tests.helper import ignore_warnings
 
 
 class GradleTest(CliTestCase):
-    test_files_dir = Path(__file__).parent.joinpath(
-        '../data/gradle/').resolve()
+    test_files_dir = Path(__file__).parent.joinpath('../data/gradle/').resolve()
     result_file_path = test_files_dir.joinpath('recursion/expected.json')
 
     @ignore_warnings
@@ -49,7 +49,8 @@ class GradleTest(CliTestCase):
         result = self.cli(
             'subset', '--target', '10%', 'gradle',
             str(self.test_files_dir.joinpath('java/app/src/test').resolve()))
-        # TODO: we need to assert on the request payload to make sure it found test list all right
+        # TODO: we need to assert on the request payload to make sure it found
+        # test list all right
         self.assertEqual(result.exit_code, 0)
         output = "--tests com.launchableinc.rocket_car_gradle.App2Test " \
                  "--tests com.launchableinc.rocket_car_gradle.AppTest " \
@@ -70,9 +71,12 @@ class GradleTest(CliTestCase):
             ),
             json={
                 "testPaths": [
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
                 ],
                 "rest": [[{'name': 'com.launchableinc.rocket_car_gradle.sub.App3Test'}]],
                 "subsettingId": 456,
@@ -98,9 +102,7 @@ class GradleTest(CliTestCase):
                       "--tests com.launchableinc.rocket_car_gradle.AppTest "
                       "--tests com.launchableinc.rocket_car_gradle.utils.UtilsTest",
                       result.output.rstrip('\n'))
-        self.assertEqual(
-            rest.read().decode(),
-            '--tests com.launchableinc.rocket_car_gradle.sub.App3Test')
+        self.assertEqual(rest.read().decode(), '--tests com.launchableinc.rocket_car_gradle.sub.App3Test')
         rest.close()
         os.unlink(rest.name)
 
@@ -116,8 +118,10 @@ class GradleTest(CliTestCase):
                 self.workspace),
             json={
                 "testPaths": [
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
                 ],
                 "rest": [
                     [{'name': 'com.launchableinc.rocket_car_gradle.sub.App2Test'}],
@@ -152,7 +156,8 @@ class GradleTest(CliTestCase):
         subset_arg = result.output.rstrip('\n')
         self.assertEqual(
             subset_arg,
-            "-PexcludeTests=com/launchableinc/rocket_car_gradle/sub/App2Test.class,com/launchableinc/rocket_car_gradle/sub/App3Test.class")
+            "-PexcludeTests=com/launchableinc/rocket_car_gradle/sub/App2Test.class,com/launchableinc/rocket_car_gradle/"
+            "sub/App3Test.class")
 
     @ignore_warnings
     @responses.activate
@@ -166,8 +171,10 @@ class GradleTest(CliTestCase):
                 self.workspace),
             json={
                 "testPaths": [
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
                 ],
                 "rest": [
                     [{'name': 'com.launchableinc.rocket_car_gradle.sub.App2Test'}],
@@ -215,8 +222,10 @@ class GradleTest(CliTestCase):
                 self.workspace),
             json={
                 "testPaths": [
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
                 ],
                 "rest": [
                     [{'name': 'com.launchableinc.rocket_car_gradle.sub.App2Test'}],
@@ -252,8 +261,7 @@ class GradleTest(CliTestCase):
                 "Exit code is not 0. The output is\n" + result.output + "\n" + result.stderr)
 
         body = gzip.decompress(responses.calls[1].request.body).decode('utf8')
-        self.assertNotIn(
-            "java.com.launchableinc.rocket_car_gradle.App2Test", body)
+        self.assertNotIn("java.com.launchableinc.rocket_car_gradle.App2Test", body)
 
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
@@ -266,9 +274,12 @@ class GradleTest(CliTestCase):
                 self.workspace),
             json={
                 "testPaths": [
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
                 ],
                 "rest": [[{'name': 'com.launchableinc.rocket_car_gradle.sub.App3Test'}]],
                 "subsettingId": 123,
@@ -306,9 +317,12 @@ class GradleTest(CliTestCase):
                 self.workspace),
             json={
                 'testPaths': [
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
                 ],
                 "rest": [[{'name': 'com.launchableinc.rocket_car_gradle.sub.App3Test'}]],
             },
@@ -331,8 +345,7 @@ class GradleTest(CliTestCase):
             "--tests com.launchableinc.rocket_car_gradle.AppTest "
             "--tests com.launchableinc.rocket_car_gradle.utils.UtilsTest",
             result.output.rstrip('\n'))
-        self.assertEqual(rest.read().decode(
-        ), '--tests com.launchableinc.rocket_car_gradle.sub.App3Test')
+        self.assertEqual(rest.read().decode(), '--tests com.launchableinc.rocket_car_gradle.sub.App3Test')
         rest.close()
         os.unlink(rest.name)
 
@@ -349,9 +362,12 @@ class GradleTest(CliTestCase):
             ),
             json={
                 'testPaths': [
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
-                    [{'type': 'class', 'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.App2Test'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.AppTest'}],
+                    [{'type': 'class',
+                      'name': 'com.launchableinc.rocket_car_gradle.utils.UtilsTest'}],
                 ],
                 "rest": [],
             },
@@ -387,12 +403,11 @@ class GradleTest(CliTestCase):
     @responses.activate
     @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_record_test_gradle(self):
-        result = self.cli('record', 'tests',  '--session', self.session,
+        result = self.cli('record', 'tests', '--session', self.session,
                           'gradle', str(self.test_files_dir) + "/**/reports")
         self.assertEqual(result.exit_code, 0)
 
-        payload = json.loads(gzip.decompress(
-            responses.calls[1].request.body).decode())
+        payload = json.loads(gzip.decompress(responses.calls[1].request.body).decode())
 
         expected = self.load_json_from_file(self.result_file_path)
         self.assert_json_orderless_equal(expected, payload)
